bread.contrib.workflows.management.commands package
===================================================

.. automodule:: bread.contrib.workflows.management.commands
   :members:
   :undoc-members:
   :show-inheritance:

Submodules
----------

bread.contrib.workflows.management.commands.activity\_diagram module
--------------------------------------------------------------------

.. automodule:: bread.contrib.workflows.management.commands.activity_diagram
   :members:
   :undoc-members:
   :show-inheritance:

bread.contrib.workflows.management.commands.dot\_diagram module
---------------------------------------------------------------

.. automodule:: bread.contrib.workflows.management.commands.dot_diagram
   :members:
   :undoc-members:
   :show-inheritance:
